pub fn init_host_platform_info(info: HostPlatformInfo)Expand description
Initialize the global HostPlatformInfo.
Should be called once during application startup, before any
Client::load_from_state calls. Subsequent calls are silently ignored.
pub fn init_host_platform_info(info: HostPlatformInfo)Initialize the global HostPlatformInfo.
Should be called once during application startup, before any
Client::load_from_state calls. Subsequent calls are silently ignored.